/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jetspeed.cache;

/**
 * <p>
 * Provides interface to Jetspeed for cache events
 * </p>
 * 
 * @author <a href="mailto:taylor@apache.org">David Sean Taylor</a>
 * @version $Id: $
 */
public interface JetspeedCacheEventListener
{

	/**
	 * REMOVE notification for cache listeners
	 * 
	 * @param cache
	 *            the Cache repoorting the change
	 * @param local
	 *            true if action was local, false if initiated by remote cache
	 * @param key
	 *            key of object
	 * @param element
	 *            content of object
	 * 
	 */
	void notifyElementRemoved(JetspeedCache cache, boolean local, Object key,
			Object element);

	/**
	 * ADDED notification for cache listeners
	 * 
	 * @param cache
	 *            the Cache repoorting the change
	 * @param local
	 *            true if action was local, false if initiated by remote cache
	 * @param key
	 *            key of object
	 * @param element
	 *            content of object
	 * 
	 */
	void notifyElementAdded(JetspeedCache cache, boolean local, Object key,
			Object element);

	/**
	 * CHANGE notification for cache listeners
	 * 
	 * @param cache
	 *            the Cache repoorting the change
	 * @param local
	 *            true if action was local, false if initiated by remote cache
	 * @param key
	 *            key of object
	 * @param element
	 *            content of object
	 * 
	 */
	void notifyElementChanged(JetspeedCache cache, boolean local, Object key,
			Object element);

	/**
	 * EVICTED notification for cache listeners
	 * 
	 * @param cache
	 *            the Cache repoorting the change
	 * @param local
	 *            true if action was local, false if initiated by remote cache
	 * @param key
	 *            key of object
	 * @param element
	 *            content of object
	 * 
	 */
	void notifyElementEvicted(JetspeedCache cache, boolean local, Object key,
			Object element);

	/**
	 * EXPIRED notification for cache listeners
	 * 
	 * @param cache
	 *            the Cache repoorting the change
	 * @param local
	 *            true if action was local, false if initiated by remote cache
	 * @param key
	 *            key of object
	 * @param element
	 *            content of object
	 * 
	 */
	void notifyElementExpired(JetspeedCache cache, boolean local, Object key,
			Object element);

}